.. mcvqoe documentation master file, created by
   sphinx-quickstart on Tue Feb 16 07:26:01 2021.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to mcvqoe's documentation!
==================================

.. toctree::
   :maxdepth: 2
   :caption: Contents:
   
.. automodule:: mcvqoe
	:members:
	
.. automodule:: mcvqoe.simulation
	:members:


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
